From e7ef07fbb6aec5632589e2739514b6cc9391fa48 Mon Sep 17 00:00:00 2001
From: johns <>
Date: Mon, 17 Jun 2002 17:48:45 +0000
Subject: [PATCH] Cleanup.

---
 src/ui/menu_proc.cpp | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/src/ui/menu_proc.cpp b/src/ui/menu_proc.cpp
index ad9266be3..5b50a9d3c 100644
--- a/src/ui/menu_proc.cpp
+++ b/src/ui/menu_proc.cpp
@@ -98,16 +98,16 @@ local int MenuButtonCurSel = -1;
 /**
 **	Find a menu by ident.
 **
 **	@param MenuId	Unique identifier for the menu.
 **
 **	@return		Pointer to the menu, NULL if menu is not found.
 */
-global Menu *FindMenu(const char *MenuId)
+global Menu *FindMenu(const char *menu_id)
 {
     Menu **menu;
 
-    if (!(menu = (Menu **) hash_find(MenuHash, (char *)MenuId))) {
-	DebugLevel0Fn("Menu `%s' not found, probably a bug.\n" _C_ MenuId);
+    if (!(menu = (Menu **) hash_find(MenuHash, (char *)menu_id))) {
+	DebugLevel0Fn("Menu `%s' not found, probably a bug.\n" _C_ menu_id);
 	return NULL;
     } else {
 	return *menu;
@@ -98,16 +98,16 @@ local int MenuButtonCurSel = -1;
 **	Find a menu by ident.
 **
-**	@param MenuId	Unique identifier for the menu.
+**	@param menu_id	Unique identifier for the menu.
 **
 **	@return		Pointer to the menu, NULL if menu is not found.